@@ -9,12 +9,21 @@
 //   A proposal to add a utility class to represent expected monad
 //   by Vicente J. Botet Escriba and Pierre Talbot, http:://wg21.link/p0323
 
+#include <cassert>
 #include "expected-main.t.hpp"
 
 #ifndef nsel_CONFIG_CONFIRMS_COMPILATION_ERRORS
 #define nsel_CONFIG_CONFIRMS_COMPILATION_ERRORS  0
 #endif
 
+#define nsel_HAVE_MAYBE_UNUSED  nsel_CPP17_000
+
+#if nsel_HAVE_MAYBE_UNUSED
+# define nsel_MAYBE_UNUSED  [[maybe_unused]]
+#else
+# define nsel_MAYBE_UNUSED  /*[[maybe_unused]]*/
+#endif
+
 // Suppress:
 // - unused parameter, for cases without assertions such as [.std...]
 #if defined(__clang__)
@@ -566,6 +575,17 @@ CASE( "make_unexpected(): Allows to create an unexpected_type<E> from an E" )
     EXPECT( u.error() == error );
 }
 
+CASE( "make_unexpected(): Allows to in-place create an unexpected_type<E> from an E" )
+{
+    const auto a = 'a';
+    const auto b =  7;
+
+    auto u = make_unexpected< std::pair<char, int> >( in_place, a, b );
+
+    EXPECT( u.error().first  == a );
+    EXPECT( u.error().second == b );
+}
+
 CASE( "make_unexpected_from_current_exception(): Allows to create an unexpected_type<std::exception_ptr> from the current exception" "[.deprecated]" )
 {
 #if nsel_P0323R <= 2
@@ -596,7 +616,7 @@ CASE( "make_unexpected_from_current_exception(): Allows to create an unexpected_
 CASE( "unexpected: C++17 and later provide unexpected_type as unexpected" )
 {
 #if nsel_CPP17_OR_GREATER || nsel_COMPILER_MSVC_VERSION > 141
-    nonstd::unexpected<int> u{7};
+    nsel_MAYBE_UNUSED nonstd::unexpected<int> u{7};
 #else
     EXPECT( !!"unexpected is not available (no C++17)." );
 #endif
@@ -1333,7 +1353,7 @@ CASE( "expected: Allows to map unexpected with or_else" " [monadic p2505r3]" )
     }
 
     const auto fallback_throw = []( int ) -> expected<int, int> { throw std::runtime_error( "or_else" ); };
-    EXPECT_THROWS_AS( (expected<int, int>{ unexpect, 42 }).or_else( fallback_throw ), std::runtime_error );
+    EXPECT_THROWS_AS( (void)(expected<int, int>{ unexpect, 42 }).or_else( fallback_throw ), std::runtime_error );
 
     const auto moveonly_fallback_to_66 = [](int) -> expected<MoveOnly, int> { return MoveOnly{ 66 }; };
     EXPECT( (expected<MoveOnly, int>{ MoveOnly{ 33 } }).or_else( moveonly_fallback_to_66 ).value() == 33 );
@@ -1354,6 +1374,8 @@ CASE( "expected: Allows to transform value" " [monadic p2505r3]" )
         EXPECT( ue.transform( mul2 ).error() == 42 );
     }
 
+    expected<std::vector<int>, int>{std::vector<int>{}}.transform([](const std::vector<int>&) { });
+
 #if nsel_P2505R >= 5
     // R5 changed remove_cvref_t to remove_cv_t in transform/transform_error, which broke data member pointer transforms,
     // because the result type must be a valid expected value type, but expressions with reference types are not.
@@ -2215,6 +2237,23 @@ CASE( "issue-58" )
     EXPECT( !unexpected.has_value() );
 }
 
+namespace issue_70 {
+
+    struct overload_addressof
+    {
+        overload_addressof * operator & ()
+        {
+            assert( 0 && "operator&() called");
+            return this;
+        } 
+    };
+} // namespace issue_70
+
+CASE("issue-70")
+{
+    nonstd::expected<issue_70::overload_addressof, int> e;
+}
+
 #if !nsel_USES_STD_EXPECTED && nsel_P2505R >= 3
 CASE( "invoke" )
 {
@@ -2253,7 +2292,7 @@ CASE( "invoke" )
 
 struct nullopt_t{};
 
-const nullopt_t nullopt{};
+nsel_MAYBE_UNUSED const nullopt_t nullopt{};
 
 /// optional expressed in expected
 
